<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://eeasy-soft.com/
 * @since      1.2.6
 *
 * @package    Easy_Map
 * @subpackage Easy_Map/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.2.6
 * @package    Easy_Map
 * @subpackage Easy_Map/includes
 * @author     Easy Soft <nashirbabu@gmail.com>
 */
class Easy_Map
{

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.2.6
	 * @access   protected
	 * @var      Easy_Map_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.2.6
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.2.6
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.2.6
	 */
	public function __construct()
	{
		if (defined('EASY_MAP_VERSION')) {
			$this->version = EASY_MAP_VERSION;
		} else {
			$this->version = '1.6.6';
		}

		$this->plugin_name = 'easy-map';

	
		$this->load_dependencies();
		$this->load_datbase_tables();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
	}

	/**
	 * Load the required database tables for this plugin.
	**/

	private function load_datbase_tables(){

		$installed_version = get_option('easy_map_version');

		//$installed_version='1.4.0';
		
		// Check if the current version is less than the minimum required version
		if (version_compare($installed_version, $this->version, '<')) {
			Easy_Map_Settings::add_version();
			Easy_Map_Settings::create_tables();
		}
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Easy_Map_Loader. Orchestrates the hooks of the plugin.
	 * - Easy_Map_i18n. Defines internationalization functionality.
	 * - Easy_Map_Admin. Defines all hooks for the admin area.
	 * - Easy_Map_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.2.6
	 * @access   private
	 */
	private function load_dependencies()
	{

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-easy-map-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-easy-map-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-easy-map-admin.php';
		require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-easy-map-settings.php';


		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-easy-map-public.php';

		$this->loader = new Easy_Map_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Easy_Map_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.2.6
	 * @access   private
	 */
	private function set_locale()
	{

		$plugin_i18n = new Easy_Map_i18n();

		$this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.2.6
	 * @access   private
	 */
	private function define_admin_hooks()
	{

		$plugin_admin = new Easy_Map_Admin($this->get_plugin_name(), $this->get_version());

		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');

		$this->loader->add_action('admin_menu', $plugin_admin, 'load_admin_pages');

		add_shortcode('easy-map-settings', [$plugin_admin, 'easy_map_settings_render']);
		add_shortcode('easy-map-edit', [$plugin_admin, 'easy_map_edit_render']);

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.2.6
	 * @access   private
	 */
	private function define_public_hooks()
	{

		$plugin_public = new Easy_Map_Public($this->get_plugin_name(), $this->get_version());

		$this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_styles',1);
		$this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_scripts',1);

		add_shortcode('easy-map', [$plugin_public, 'easy_map_render']);
		
		add_shortcode('easy-map-marker', [$plugin_public, 'easy_map_marker_render']);

		add_shortcode('easy-map-polyline', [$plugin_public, 'easy_map_polyline_render']);

		add_shortcode('easy-map-drawing', [$plugin_public, 'easy_map_drawing_render']);
	
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.2.6
	 */
	public function run()
	{
		$this->loader->run();
	}
	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.2.6
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name()
	{
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.2.6
	 * @return    Easy_Map_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader()
	{
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.2.6
	 * @return    string    The version number of the plugin.
	 */
	public function get_version()
	{
		return $this->version;
	}
}
